@@ -18,8 +18,13 @@ class DirectoryTreeView(TemplateView):
     def get_context_data(self, **kwargs):
         context = super().get_context_data(**kwargs)
 
-        base_dir = settings.MEDIA_ROOT
+        media_root = settings.MEDIA_ROOT
+        media_url = settings.MEDIA_URL
+        if not media_root or not media_url:
+            context['error'] = "error : undefind MEDIA_ROOT or MEDIA_URL in setting"
+            return context
+
         pattern = r".*"
-        obj = DirectoryTree(base_dir, pattern=pattern)
-        context['folder_tree'] = json.dumps(obj.dict_file)        
+        obj = DirectoryTree(media_root, pattern=pattern)
+        context['folder_tree'] = json.dumps(obj.dict_file)
         return context
\ No newline at end of file
